@@ -15,7 +15,9 @@ aictab.polr <-
     Results$ModelLik<-exp(-0.5*Results$Delta_AICc)                #compute model likelihood required to compute Akaike weights
     Results$AICcWt<-Results$ModelLik/sum(Results$ModelLik)        #compute Akaike weights
     Results$LL <- unlist(lapply(X=cand.set, FUN=function(i) logLik(i)[1]))      
-    
+
+    ##check if some models are redundant
+    if(length(unique(Results$AICc)) != length(cand.set)) warning("\nCheck model structure carefully as some models may be redundant\n")
     
     #rename correctly to AIC
     if(second.ord==FALSE) {
